@@ -1,4 +1,4 @@
 buffer <- function(){
     buffer <- file.path(tempdir(), "buffer.txt")
-    cat(readLines(buffer), "\n")
+    message(readLines(buffer))
 }
