@@ -3,7 +3,7 @@ function()
 #   Set a monitor for dic
 {
     command <- "DevianceEmbed.SetVariable('*');DevianceEmbed.SetGuard;DevianceEmbed.Set"
-    .C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE="BRugs")
+    .CmdInterpreter(command)
     if(getOption("BRugsVerbose")) 
         buffer()
 }
